@@ -1,3 +1,5 @@
+# -*- Perl -*-
+#
 # TODO
 # * chord_pos
 #   - support arbitrary? voice counts (would need doubling rules?) Extra
@@ -26,11 +28,11 @@ use 5.010;
 use strict;
 use warnings;
 
-use Carp qw(croak);
+use Carp qw/croak/;
 use List::MoreUtils qw(all uniq);
 use List::Util qw(max min);
 
-our $VERSION = '0.52';
+our $VERSION = '0.55';
 
 my $DEG_IN_SCALE = 12;
 
@@ -44,7 +46,7 @@ sub new {
 
   $self->{_DEG_IN_SCALE} = int( $param{DEG_IN_SCALE} // $DEG_IN_SCALE );
   if ( $self->{_DEG_IN_SCALE} < 2 ) {
-    croak("degrees in scale must be greater than one");
+    croak 'degrees in scale must be greater than one';
   }
 
   bless $self, $class;
@@ -57,7 +59,7 @@ sub new {
 
 sub chord_inv {
   my ( $self, $pitch_set, %params ) = @_;
-  croak "pitch set reference required"
+  croak 'pitch set reference required'
     unless defined $pitch_set and ref $pitch_set eq 'ARRAY';
 
   my $max_pitch = max(@$pitch_set);
@@ -85,7 +87,7 @@ sub chord_inv {
   }
 
   if ( exists $params{'inv_num'} ) {
-    croak "inversion number out of range"
+    croak 'inversion number out of range'
       if $params{'inv_num'} !~ m/^\d+$/
         or $params{'inv_num'} < 1
         or $params{'inv_num'} > @inversions;
@@ -97,7 +99,7 @@ sub chord_inv {
 
 sub chord_pos {
   my ( $self, $pitch_set, %params ) = @_;
-  croak "pitch set reference required"
+  croak 'pitch set reference required'
     unless defined $pitch_set and ref $pitch_set eq 'ARRAY';
 
   my (
@@ -258,7 +260,7 @@ sub chord_pos {
 # Change a pitch set collection (vertical) into voices (horizontal)
 sub chords2voices {
   my ( $self, $pitch_sets ) = @_;
-  croak "not a list of pitch sets" unless ref $pitch_sets->[0] eq 'ARRAY';
+  croak 'not a list of pitch sets' unless ref $pitch_sets->[0] eq 'ARRAY';
 
   # Nothing to swap, change nothing
   return $pitch_sets if @$pitch_sets < 2;
@@ -276,7 +278,7 @@ sub chords2voices {
 sub scale_degrees {
   my ( $self, $dis ) = @_;
   if ( defined $dis ) {
-    croak "scale degrees value must be positive integer greater than 1\n"
+    croak 'scale degrees value must be positive integer greater than 1'
       if !defined $dis
         or $dis !~ /^\d+$/
         or $dis < 2;
@@ -339,8 +341,7 @@ Look under the C<eg> directory for example scripts.
 =head1 METHODS
 
 Methods may croak or die, depending on whether there is a problem with
-the input or internal code; use L<Try::Tiny> or block C<eval> if this
-is an issue.
+the input or internal code; use L<Try::Tiny> if this is an issue.
 
 =over 4
 
@@ -518,10 +519,10 @@ Jeremy Mates E<lt>jmates@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011-2012 Jeremy Mates
+Copyright (C) 2011-2013 Jeremy Mates
 
 This library is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself, either Perl version 5.14 or, at
+under the same terms as Perl itself, either Perl version 5.16 or, at
 your option, any later version of Perl 5 you may have available.
 
 =cut
